@@ -1,3 +1,5 @@
+from django.db.models.signals import post_save
+
 __all__ = [
     'RegisteredBindingMetaClass',
     'registered_binding_classes',
@@ -21,6 +23,13 @@ class RegisteredBindingMetaClass(type):
             binding_class.stream = stream
             binding_class._registred_actions = {}
 
+            if (
+                binding_class.model and
+                getattr(binding_class, 'post_save_retrieve', False) == True and
+                hasattr(binding_class, '_post_save_retrieve')
+            ):
+                post_save.connect(binding_class._post_save_retrieve, sender=binding_class.model)
+
             for method_name in dir(binding_class):
                 method = getattr(binding_class, method_name)
                 is_bind = getattr(method, 'is_bind', False)
